@@ -1,6 +1,8 @@
 """
 """
 
+from packaging import version
+
 from ...config import Config
 
 
@@ -20,6 +22,14 @@ except ImportError:
 
 else:
 
+    # Make OMP_NUM_THREADS impact both inter-op and intra-op
+    if version.parse(torch.__version__) >= version.parse('2.4'):
+        num_threads = torch.get_num_threads()
+        try:
+            torch.set_num_interop_threads(num_threads)
+        except RuntimeError: # Already set
+            pass
+
     if Config.zero_gpu_v2:
         from . import patching as _patching
     else: # pragma: no cover
@@ -33,6 +43,7 @@ else:
     _move = _patching.move
     _is_in_bad_fork = _patching.is_in_bad_fork
 
+
 patch = _patch
 unpatch = _unpatch
 pack = _pack
